@@ -23,6 +23,12 @@ class variavel:
         self.intervalo_total = intervalo_total
         
     def inserirFP(self, intervalo, nome):
+        """
+        Utilizada para inserir uma função de pertinência à uma variável
+
+        :param intervalo: tupla que define o intervalo da função de pertinência. com 2 valores cria uma função de pertinência gaussiana; com 3 valores cria uma função de pertinência triangular; com 4 valores cria uma função de pertinência trapezoidal;
+        :param nome: str armazena o nome da função de pertinêncoa.
+        """
         var = funcao_pertinencia.novaFP(intervalo, nome)
         if var != 0:    
             self.variaveis.append(var)
@@ -39,6 +45,10 @@ class variavel:
         plt.ylabel('PERTINÊNCIA')
         
     def visualizar(self):
+        """
+        Utilizada para gerar um gráfico com todas as funções de pertinência
+        inseridas na variável.
+        """
         if self.variavel_valido():
             self.visualizar_base()
             plt.show()
